from emod_api import schema_to_class as s2c
import emod_api.interventions.common as common
import emod_api.interventions.utils as utils
from emodpy_tbhiv.interventions import purge_campaign_event

co_event = "BcgDistributed"

def BCG(
        camp,
        trigger_treatment_list,
        initial_efficacy=1.0,
        vaccine_take=1,
        age_take_decay=1.0,
        box_duration=365,
        immune_decay=3650, 
        start_day=0,
        duration=-1,
        property_restrictions_list=[],
        nodeIDs=[],
        black_period=0,
        black_trigger='Blackout',
        event_name='Vaccine Health Seeking'):
    """
    BCG Vaccine
    :param TBD
    Note start_day is initialized as 1, recommend that this be aligned with the start of the simulation
    """
    # First, get the objects
    schema_path = camp.schema_path

    act_intervention = s2c.get_class_with_defaults( "BCGVaccine", schema_path )
    waning = s2c.get_class_with_defaults( "WaningEffectBoxExponential", schema_path )
    bcast_intervention = s2c.get_class_with_defaults( "BroadcastEvent", schema_path )

    # Second, hook them up
    act_intervention.Waning_Config = waning
    bcast_intervention.Broadcast_Event = camp.get_send_trigger( co_event )

    # Third, do the actual settings
    act_intervention.Vaccine_Take = vaccine_take
    act_intervention.Vaccine_Take_Age_Decay_Rate = age_take_decay
    waning.Initial_Effect = initial_efficacy
    waning.Box_Duration = box_duration
    waning.Decay_Time_Constant = immune_decay

    event = common.TriggeredCampaignEvent( camp, start_day,event_name, trigger_treatment_list, [ act_intervention, bcast_intervention ], Nodeset_Config=utils.do_nodes( camp.schema_path, nodeIDs ), Duration=duration, Property_Restrictions=property_restrictions_list )
    purge_campaign_event( event )
    return event

def new_intervention_as_file( camp, filename=None ):
    camp.add( BCG( camp, trigger_treatment_list=[ "Births" ] ) )
    if filename is None:
        filename = "bcg.json"
    camp.save( filename )
    return filename

